summaryrefslogtreecommitdiff
path: root/include/builtinmodes.h
diff options
context:
space:
mode:
authorattilamolnar <attilamolnar@hush.com>2013-07-20 20:59:48 +0200
committerattilamolnar <attilamolnar@hush.com>2013-07-24 18:10:34 +0200
commit1a775c11c27c3b786c6850d8a9efeaf8d9c1d2c0 (patch)
treefba58774f678e3c5d5599d76fc37326510f2e59d /include/builtinmodes.h
parentc265641c0a9a9b0a4686e1ea313876c16b4700ad (diff)
umode_s Rewrite ProcessNoticeMasks() and remove a few related useless functions
Diffstat (limited to 'include/builtinmodes.h')
-rw-r--r--include/builtinmodes.h22
1 files changed, 7 insertions, 15 deletions
diff --git a/include/builtinmodes.h b/include/builtinmodes.h
index 31b208d52..b1e5c3ccd 100644
--- a/include/builtinmodes.h
+++ b/include/builtinmodes.h
@@ -150,32 +150,24 @@ class ModeUserInvisible : public SimpleUserModeHandler
*/
class ModeUserServerNoticeMask : public ModeHandler
{
- /** Create a displayable mode string for this users snomasks
- * @param user The user whose notice masks to format
- * @return The notice mask character sequence
- */
- std::string FormatNoticeMasks(User* user);
-
/** Process a snomask modifier string, e.g. +abc-de
* @param user The target user
* @param sm A sequence of notice mask characters
* @return The cleaned mode sequence which can be output,
* e.g. in the above example if masks c and e are not
* valid, this function will return +ab-d
*/
- std::string ProcessNoticeMasks(User* user, const char *sm);
-
- /** Changed a specific notice mask value
- * @param user The target user
- * @param sm The server notice mask to change
- * @param value An on/off value for this mask
- */
- void SetNoticeMask(User* user, unsigned char sm, bool value);
+ std::string ProcessNoticeMasks(User* user, const std::string& input);
public:
ModeUserServerNoticeMask();
ModeAction OnModeChange(User* source, User* dest, Channel* channel, std::string &parameter, bool adding);
void OnParameterMissing(User* user, User* dest, Channel* channel);
+
+ /** Create a displayable mode string of the snomasks set on a given user
+ * @param user The user whose notice masks to format
+ * @return The notice mask character sequence
+ */
std::string GetUserParameter(User* user);
};
@@ -150,32 +150,24 @@ class ModeUserInvisible : public SimpleUserModeHandler
/** Process a snomask modifier string, e.g. +abc-de
* @param user The target user
- * @param sm A sequence of notice mask characters
+ * @param input A sequence of notice mask characters
* @return The cleaned mode sequence which can be output,
* e.g. in the above example if masks c and e are not